@@ -17,10 +17,22 @@
 # the License.
 #
 
-__version__ = "2.0.0"
+__version__ = "2.3.0"
+
+
+def get_ordinal(number):
+    """Produces an ordinal (1st, 2nd, 3rd, 4th) from a number"""
+
+    if number == 1:
+        return 'st'
+    elif number == 2:
+        return 'nd'
+    elif number == 3:
+        return 'rd'
+    else:
+        return 'th'
 
-# Make sure QGIS plugin can import openrouteservice-py
 
 from openrouteservice.client import Client
 ## Allow sphinx to pick up these symbols for the documentation.
-#__all__ = ["Client"]
+# __all__ = ["Client"]
