@@ -19,7 +19,11 @@
 
 """Performs requests to the ORS directions API."""
 
-from openrouteservice import validator, deprecation
+from openrouteservice import deprecation
+from openrouteservice.optimization import optimization, Job, Vehicle
+
+import warnings
+
 
 def directions(client,
                coordinates,
@@ -33,16 +37,19 @@ def directions(client,
                geometry_simplify=None,
                instructions=None,
                instructions_format=None,
+               alternative_routes=None,
                roundabout_exits=None,
                attributes=None,
                maneuvers=None,
                radiuses=None,
                bearings=None,
+               skip_segments=None,
                continue_straight=None,
                elevation=None,
                extra_info=None,
                suppress_warnings=None,
                optimized=None,
+               optimize_waypoints=None,
                options=None,
                validate=True,
                dry_run=None):
@@ -58,7 +65,7 @@ def directions(client,
         directions. One of ["driving-car", "driving-hgv", "foot-walking",
         "foot-hiking", "cycling-regular", "cycling-road","cycling-mountain",
         "cycling-electric",]. Default "driving-car".
-    :type mode: string
+    :type profile: string
 
     :param format: Specifies the response format. One of ['json', 'geojson', 'gpx']. Default "json".
         Geometry format for "json" is Google's encodedpolyline. The GPX schema the response is validated
@@ -98,6 +105,12 @@ def directions(client,
         One of ["text", "html"]. Default "text".
     :type instructions_format: string
 
+    :param alternative_routes: Specifies whether alternative routes are computed,
+        and parameters for the algorithm determining suitable alternatives. Expects
+        3 keys: share_factor (float), target_count (int), weight_factor (float).
+        More on https://openrouteservice.org/dev/#/api-docs/v2/directions/{profile}/geojson/post.
+    :type alternative_routes: dict[int|float]
+
     :param roundabout_exits: Provides bearings of the entrance and all passed
         roundabout exits. Adds the 'exit_bearings' array to the 'step' object
         in the response. Default False.
@@ -132,6 +145,11 @@ def directions(client,
         waypoint may be reached.
     :type bearings: list or tuple or lists or tuples
 
+    :param skip_segments: Specifies the segments that should be skipped in the route calculation.
+        A segment is the connection between two given coordinates and the counting starts with 1
+        for the connection between the first and second coordinate.
+    :type skip_segments: list[int]
+
     :param continue_straight: Forces the route to keep going straight at waypoints
         restricting u-turns even if u-turns would be faster. This setting
         will work for all profiles except for driving-*. In this case you will
@@ -154,11 +172,17 @@ def directions(client,
     :param optimized: If set False, forces to not use Contraction Hierarchies.
     :type optimized: bool
 
-    :param options: Refer to https://go.openrouteservice.org/documentation for
+    :param options: Refer to https://openrouteservice.org/dev/#/api-docs/v2/directions/{profile}/geojson/post for
         detailed documentation. Construct your own dict() following the example
         of the minified options object. Will be converted to json automatically.
     :type options: dict
 
+    :param optimize_waypoints: If True, a `Vroom <https://github.com/VROOM-Project/vroom>`_ instance (ORS optimization
+        endpoint) will optimize the `via` waypoints, i.e. all coordinates between the first and the last. It assumes
+        the first coordinate to be the start location and the last coordinate to be the end location. Only requests with
+        a minimum of 4 coordinates, no routing options and fastest weighting. Default False.
+    :type optimize_waypoints: bool
+
     :param validate: Specifies whether parameters should be validated before sending the request. Default True.
     :type validate: bool
     
@@ -172,8 +196,16 @@ def directions(client,
     :rtype: call to Client.request()
     """
 
-    if validate:
-        validator.validator(locals(), 'directions')
+    # call optimization endpoint and get new order of waypoints
+    if optimize_waypoints is not None and not dry_run:
+        if len(coordinates) <= 3:
+            warnings.warn("Less than 4 coordinates, nothing to optimize!", UserWarning)
+        elif options:
+            warnings.warn("Options are not compatible with optimization.", UserWarning)
+        elif preference == 'shortest':
+            warnings.warn("Shortest is not compatible with optimization.", UserWarning)
+        else:
+            coordinates = _optimize_waypoint_order(client, coordinates, profile)
 
     params = {"coordinates": coordinates}
 
@@ -195,11 +227,7 @@ def directions(client,
         params["geometry"] = geometry
 
     if geometry_simplify is not None:
-        # not checked on backend, check here
-        if extra_info:
-            params["geometry_simplify"] = False
-        else:
-            params["geometry_simplify"] = geometry_simplify
+        params["geometry_simplify"] = geometry_simplify
 
     if instructions is not None:
         params["instructions"] = instructions
@@ -207,6 +235,9 @@ def directions(client,
     if instructions_format:
         params["instructions_format"] = instructions_format
 
+    if alternative_routes:
+        params["alternative_routes"] = alternative_routes
+
     if roundabout_exits is not None:
         params["roundabout_exits"] = roundabout_exits
 
@@ -222,6 +253,9 @@ def directions(client,
     if bearings:
         params["bearings"] = bearings
 
+    if skip_segments:
+        params["skip_segments"] = skip_segments
+
     if continue_straight is not None:
         params["continue_straight"] = continue_straight
 
@@ -245,3 +279,35 @@ def directions(client,
         params['options'] = options
 
     return client.request("/v2/directions/" + profile + '/' + format, {}, post_json=params, dry_run=dry_run)
+
+
+def _optimize_waypoint_order(client, coordinates, profile):
+
+    start = coordinates[0]
+    end = coordinates[-1]
+    veh = [Vehicle(
+        id=0,
+        profile=profile,
+        start=start,
+        end=end
+    )]
+
+    jobs = []
+    for idx, coord in enumerate(coordinates[1:-1]):
+        jobs.append(Job(
+            id=idx,
+            location=coord
+        ))
+
+    params = {
+        'jobs': jobs,
+        'vehicles': veh
+    }
+
+    optimization_res = optimization(client, **params)
+
+    coordinates = []
+    for step in optimization_res['routes'][0]['steps']:
+        coordinates.append(step['location'])
+
+    return coordinates
