@@ -19,8 +19,6 @@
 
 """Performs requests to the ORS Matrix API."""
 
-from openrouteservice import validator
-
 
 def distance_matrix(client, locations,
                     profile='driving-car',
@@ -84,9 +82,6 @@ def distance_matrix(client, locations,
     :rtype: call to Client.request()
     """
 
-    if validate:
-        validator.validator(locals(), 'distance_matrix')
-
     params = {
         "locations": locations,
     }
