@@ -17,7 +17,6 @@
 
 """Performs requests to the ORS elevation API."""
 
-from openrouteservice import validator
 
 def elevation_point(client, format_in, geometry,
                     format_out='geojson',
@@ -46,21 +45,22 @@ def elevation_point(client, format_in, geometry,
     :returns: correctly formatted parameters
     :rtype: Client.request()
     """
-    if validate:
-        validator.validator(locals(), 'elevation_point')
 
-    params = {'format_in': format_in,
-              'geometry': geometry,
-              'format_out': format_out,
-              'dataset': dataset}    
-            
+    params = {
+        'format_in': format_in,
+        'geometry': geometry,
+        'format_out': format_out,
+        'dataset': dataset
+    }
+
     return client.request('/elevation/point', {}, post_json=params, dry_run=dry_run)
 
+
 def elevation_line(client, format_in, geometry,
-                    format_out='geojson',
-                    dataset='srtm',
-                    validate=True,
-                    dry_run=None):
+                   format_out='geojson',
+                   dataset='srtm',
+                   validate=True,
+                   dry_run=None):
     """
     POSTs 2D point to be enriched with elevation.
     
@@ -85,12 +85,12 @@ def elevation_line(client, format_in, geometry,
     :returns: correctly formatted parameters
     :rtype: Client.request()
     """
-    if validate:
-        validator.validator(locals(), 'elevation_line')
 
-    params = {'format_in': format_in,
-              'geometry': geometry,
-              'format_out': format_out,
-              'dataset': dataset}    
-            
-    return client.request('/elevation/line', {}, post_json=params, dry_run=dry_run)
\ No newline at end of file
+    params = {
+        'format_in': format_in,
+        'geometry': geometry,
+        'format_out': format_out,
+        'dataset': dataset
+    }
+
+    return client.request('/elevation/line', {}, post_json=params, dry_run=dry_run)
