@@ -21,40 +21,49 @@
 Defines exceptions that are thrown by the ORS client.
 """
 
+
 class ValidationError(Exception):
     """Something went wrong during cerberus validation"""
+
     def __init__(self, errors):
         msg = '\n'.join(["{}".format(str(errors))])
         Exception.__init__(self, msg)
 
+
 class ApiError(Exception):
     """Represents an exception returned by the remote API."""
+
     def __init__(self, status, message=None):
         self.status = status
         self.message = message
 
     def __str__(self):
         if self.message is None:
-            return self.status
+            return str(self.status)
         else:
             return "%s (%s)" % (self.status, self.message)
 
+
 class HTTPError(Exception):
     """An unexpected HTTP error occurred."""
+
     def __init__(self, status_code):
         self.status_code = status_code
 
     def __str__(self):
         return "HTTP Error: %d" % self.status_code
 
+
 class Timeout(Exception):
     """The request timed out."""
     pass
 
+
 class _RetriableRequest(Exception):
     """Signifies that the request can be retried."""
     pass
 
+
 class _OverQueryLimit(ApiError, _RetriableRequest):
     """Signifies that the request failed because the client exceeded its query rate limit.
 
