@@ -17,7 +17,7 @@
 
 """Performs requests to the ORS isochrones API."""
 
-from openrouteservice import validator, deprecation
+from openrouteservice import deprecation
 
 
 def isochrones(client, locations,
@@ -94,9 +94,6 @@ def isochrones(client, locations,
     :rtype: call to Client.request()
     """
 
-    if validate:
-        validator.validator(locals(), 'isochrones')
-
     params = {
         "locations": locations
     }
@@ -119,7 +116,7 @@ def isochrones(client, locations,
     interval = interval or segments
     if interval:
         params['interval'] = interval
-        
+
     if units:
         params["units"] = units
 
